Pocket TTS - Streaming

# Pocket TTS

Hello world. I am Kyutai's Pocket TTS. I'm fast enough to run on small CPUs. I hope you'll like me.
Optional voice URL (leave empty to use default voice):

Supports: http://, https://, or hf:// URLs.
You can also use predefined voices:
"alba", "marius", "javert", "jean", "fantine", "cosette", "eponine", "azelma".

Or upload a WAV file for voice cloning:

Upload a WAV file to use as voice reference. Takes precedence over voice URL.

### Generated Audio

Download